%global pypi_name ansible-lint
%global module_name ansible_lint
%global commitId b706ccc1c00d02f8fafa76905b846e36360adf20

Name:           %{pypi_name}
Version:        6.14.3
Release:        1%{?dist}
Summary:        Checks playbooks for practices and behaviour that could potentially be improved

License:        GPLv3
URL:            https://github.com/ansible/ansible-lint
Source0:        ansible-lint-b706ccc1c00d02f8fafa76905b846e36360adf20.tar.gz
BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-pip
BuildRequires:  python%{python3_pkgversion}-rpm-macros
BuildRequires:  python%{python3_pkgversion}-setuptools >= 42
BuildRequires:  python%{python3_pkgversion}-setuptools_scm+toml >= 3.5.0
BuildRequires:  python%{python3_pkgversion}-wheel

%{?python_provide:%python_provide python%{python3_pkgversion}-%{pypi_name}}
Requires:       ansible-core >= 2.14.0
Requires:       git-core
Requires:       python%{python3_pkgversion}-ansible-compat >= 3.0.1
Requires:       python%{python3_pkgversion}-black >= 22.8.0
Requires:       python%{python3_pkgversion}-filelock >= 3.3.0
Requires:       python%{python3_pkgversion}-jsonschema >= 4.10.0
Requires:       python%{python3_pkgversion}-packaging >= 21.3
Requires:       python%{python3_pkgversion}-pyyaml >= 5.4.1
Requires:       python%{python3_pkgversion}-rich >= 12.0.0
Requires:       python%{python3_pkgversion}-ruamel-yaml < 0.18
Requires:       python%{python3_pkgversion}-ruamel-yaml >= 0.17.21
Requires:       python%{python3_pkgversion}-subprocess-tee >= 0.4.1
Requires:       python%{python3_pkgversion}-wcmatch >= 8.1.2
Requires:       yamllint >= 1.30.0

%description
%{summary}

%prep
%autosetup -n %{pypi_name}-%{commitId}
cat <<EOF > setup.cfg
[metadata]
name = %{pypi_name}
author = Will Thames
author_email = will@thames.id.au
maintainer = Ansible by Red Hat
maintainer_email = info@ansible.com
url = %{url}
project_urls =
  Bug Tracker = %{url}/issues
  Release Management = %{url}/releases
  CI: GitHub = %{url}/actions?query=workflow:tox+branch:main+event:push
  Code of Conduct = https://docs.ansible.com/ansible/latest/community/code_of_conduct.html
  Documentation = https://ansible-lint.readthedocs.io/
  Mailing lists = https://docs.ansible.com/ansible/latest/community/communication.html#asking-questions-over-email
  Source Code = %{url}
license = %{license}
license_files = COPYING
description = Checks playbooks for practices and behavior that could potentially be improved
long_description = file: README.md
long_description_content_type = text/markdown
classifiers =
  Development Status :: 5 - Production/Stable
  Environment :: Console
  Intended Audience :: Developers
  Intended Audience :: Information Technology
  Intended Audience :: System Administrators
  Operating System :: MacOS
  Operating System :: POSIX
  License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)
  Programming Language :: Python :: 3
  Programming Language :: Python :: 3.9
  Programming Language :: Python :: 3.10
  Programming Language :: Python :: 3.11
  Programming Language :: Python :: 3 :: Only
  Programming Language :: Python
  Topic :: System :: Systems Administration
  Topic :: Software Development :: Quality Assurance
  Topic :: Software Development :: Testing
  Topic :: Utilities
keywords =
  ansible
  lint

[options]
use_scm_version = True
python_requires = >=3.9
package_dir =
  = src
packages = find:
zip_safe = False

[options.entry_points]
console_scripts =
  ansible-lint = ansiblelint.__main__:_run_cli_entrypoint

[options.packages.find]
where = src

[options.package_data]
* =
  py.typed
  **/*.json
  **/*.yml
  **/*.yaml
  **/*.md
EOF

%build
# Here we set upstream version based on setuptools_scm documentation
# this is done to avoid the following error:
# LookupError: setuptools-scm was unable to detect version
# since we are not importing a .git repository in the tarball
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%{__python3} -m pip wheel --wheel-dir %{_builddir}/wheel --no-deps --use-pep517 --no-build-isolation --disable-pip-version-check --no-clean --progress-bar off --verbose .

%install
# Here we set upstream version based on setuptools_scm documentation
# this is done to avoid the following error:
# LookupError: setuptools-scm was unable to detect version
# since we are not importing a .git repository in the tarball
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%{__python3} -m pip install --root %{buildroot} --no-deps --disable-pip-version-check --progress-bar off --verbose --ignore-installed --no-warn-script-location --no-index --no-cache-dir --find-links %{_builddir}/wheel %{pypi_name}==%{version}
sed -i 's/pip/rpm/' %{buildroot}/%{python3_sitelib}/%{module_name}-%{version}.dist-info/INSTALLER
rm -fv %{buildroot}/%{python3_sitelib}/%{module_name}-%{version}.dist-info/{RECORD,REQUESTED}

%files
%license COPYING
%doc README.md
%{_bindir}/ansible-lint
%{python3_sitelib}/ansiblelint
%{python3_sitelib}/%{module_name}-%{version}.dist-info

%changelog
* Mon Apr 17 2023 imitri Savineau <dsavinea@redhat.com> - 6.14.3-1
- Update to 6.14.3

* Fri Oct 14 2022 Dimitri Savineau <dsavinea@redhat.com> - 6.8.2-1
- Update to 6.8.2

* Thu Aug 18 2022 James Marshall <jamarsha@redhat.com> - 6.2.2-1
- Update ansible-lint 6.2.2
- Cherry-pick https://github.com/ansible/ansible-lint/pull/2307

* Fri Apr 08 2022 Dimitri Savineau <dsavinea@redhat.com> - 6.0.2-3
- Depends on ansible-core 2.13

* Sat Mar 26 2022 Paul Belanger <pabelanger@redhat.com> - 6.0.2-2
- rebuilt for CPaaS

* Thu Mar 24 2022 Dimitri Savineau <dsavinea@redhat.com> - 6.0.2-1
- Update to 6.0.2

* Fri Mar 18 2022 Dimitri Savineau <dsavinea@redhat.com> - 6.0.1-1
- Update to 6.0.1

* Tue Mar 15 2022 Dimitri Savineau <dsavinea@redhat.com> - 6.0.0-1
- Update to 6.0.0

* Mon Mar 7 2022 Yanis Guenane <yguenane@redhat.com> - 5.4.0-1
- Update to 5.4.0

* Mon Sep 13 2021 Evgeni Golov - 5.0.8-2
- Build against Python 3.8

* Fri May 14 2021 Evgeni Golov - 5.0.8-1
- Release ansible-lint 5.0.8

* Wed Mar 31 2021 Evgeni Golov - 5.0.6-1
- Update to 5.0.6

* Tue Nov 10 2020 Evgeni Golov 4.2.0-2
- fix requires

* Mon Jul 27 2020 Evgeni Golov 4.2.0-1
- package ansible-lint
-
